aboutsummaryrefslogtreecommitdiff
path: root/gui/options.cpp
diff options
context:
space:
mode:
authorAlexander Tkachev2019-07-21 20:52:16 +0700
committerMatan Bareket2019-07-30 14:51:41 -0400
commitf7902583bc7a3aac702d10488e47805742753d0a (patch)
treedeee81106b4298dedebd8ad390a2fa15560983ca /gui/options.cpp
parente4da63823ad363cfd24b15bc671aa6cb8f5b43f1 (diff)
downloadscummvm-rg350-f7902583bc7a3aac702d10488e47805742753d0a.tar.gz
scummvm-rg350-f7902583bc7a3aac702d10488e47805742753d0a.tar.bz2
scummvm-rg350-f7902583bc7a3aac702d10488e47805742753d0a.zip
GUI: Change 'Wi-Fi Sharing' tab name to 'LAN'
Diffstat (limited to 'gui/options.cpp')
-rw-r--r--gui/options.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/gui/options.cpp b/gui/options.cpp
index 245b985c43..6be08d40cb 100644
--- a/gui/options.cpp
+++ b/gui/options.cpp
@@ -1763,10 +1763,10 @@ void GlobalOptionsDialog::build() {
#endif USE_LIBCURL
#ifdef USE_SDL_NET
//
// 8) The Wi-Fi Sharing tab (local "cloud" webserver)
//
- tab->addTab(_c("Wi-Fi Sharing", context));
- addWiFiSharingControls(tab, "GlobalOptions_WiFiSharing.", context);
+ tab->addTab(_c("LAN", context));
+ addNetworkControls(tab, "GlobalOptions_Network.", context);
#endif // USE_SDL_NET
#endif // USE_CLOUD
@@ -1903,7 +1903,7 @@ void GlobalOptionsDialog::addCloudControls(GuiObject *boss, const Common::String
#endif // USE_LIBCURL
#ifdef USE_SDL_NET
-void GlobalOptionsDialog::addWiFiSharingControls(GuiObject *boss, const Common::String &prefix, const char *context) {
+void GlobalOptionsDialog::addNetworkControls(GuiObject *boss, const Common::String &prefix, const char *context) {
_runServerButton = new ButtonWidget(boss, prefix + "RunServerButton", _("Run server"), _("Run local webserver"), kRunServerCmd);
_serverInfoLabel = new StaticTextWidget(boss, prefix + "ServerInfoLabel", _("Not running"));
@@ -1918,10 +1918,10 @@ void GlobalOptionsDialog::addWiFiSharingControls(GuiObject *boss, const Common::
_serverPort = new EditTextWidget(boss, prefix + "ServerPortEditText", Common::String::format("%u", port), 0);
_serverPortClearButton = addClearButton(boss, prefix + "ServerPortClearButton", kServerPortClearCmd);
- _featureDescriptionLine1 = new StaticTextWidget(boss, prefix + "FeatureDescriptionLine1", _c("Run server to manage files with browser (in the same Wi-Fi network).", context), "", ThemeEngine::kFontStyleNormal);
+ _featureDescriptionLine1 = new StaticTextWidget(boss, prefix + "FeatureDescriptionLine1", _c("Run server to manage files with browser (in the same network).", context), "", ThemeEngine::kFontStyleNormal);
_featureDescriptionLine2 = new StaticTextWidget(boss, prefix + "FeatureDescriptionLine2", _c("Closing options dialog will stop the server.", context), "", ThemeEngine::kFontStyleNormal);
- reflowWiFiSharingTabLayout();
+ reflowNetworkTabLayout();
}
#endif // USE_SDL_NET
@@ -2403,7 +2403,7 @@ void GlobalOptionsDialog::handleTickle() {
#ifdef USE_SDL_NET
if (LocalServer.isRunning() != _serverWasRunning) {
_serverWasRunning = !_serverWasRunning;
- reflowWiFiSharingTabLayout();
+ reflowNetworkTabLayout();
}
#endif // USE_SDL_NET
#endif // USE_CLOUD
@@ -2450,7 +2450,7 @@ void GlobalOptionsDialog::reflowLayout() {
setupCloudTab();
#endif // USE_LIBCURL
#ifdef USE_SDL_NET
- reflowWiFiSharingTabLayout();
+ reflowNetworkTabLayout();
#endif // USE_SDL_NET
#endif // USE_CLOUD
}
@@ -2592,7 +2592,7 @@ void GlobalOptionsDialog::shiftWidget(Widget *widget, const char *widgetName, in
#endif // USE_LIBCURL
#ifdef USE_SDL_NET
-void GlobalOptionsDialog::reflowWiFiSharingTabLayout() {
+void GlobalOptionsDialog::reflowNetworkTabLayout() {
bool serverIsRunning = LocalServer.isRunning();
if (_runServerButton) {
@@ -1763,10 +1763,10 @@ void GlobalOptionsDialog::build() {
#ifdef USE_SDL_NET
//
- // 8) The Wi-Fi Sharing tab (local "cloud" webserver)
+ // 8) The LAN tab (local "cloud" webserver)
//